Crate disk_cleaner

Crate disk_cleaner 

Re-exports

pub use projects::analyze;
pub use projects::clean;
pub use projects::dir_size;
pub use projects::scan;
pub use projects::Project;
pub use projects::ProjectAnalysis;
pub use projects::ProjectType;
pub use projects::ScanError;
pub use projects::ScanOptions;

Modules

projects
Locate build-tool artifact directories across many project types and tell you how much disk space they waste — optionally deleting them.
tui

Structs

DiskItem

Enums

FileInfo