pub enum ProjectType {
Show 23 variants
Cargo,
Node,
Unity,
Stack,
Cabal,
SBT,
Maven,
Gradle,
CMake,
Unreal,
Jupyter,
Python,
Pixi,
Composer,
Pub,
Elixir,
Swift,
Zig,
Godot4,
Dotnet,
Turborepo,
Terraform,
Cocoapods,
}Expand description
A recognized development-project ecosystem (Cargo, Node, Unity, …).
A single directory may be classified as several ProjectTypes at once —
for example a directory with both Cargo.toml and package.json is
{Cargo, Node}. Variant ordering follows declaration order and is used to
keep type_name() and similar output stable and deterministic rather than
dependent on filesystem readdir order.
Variants
Cargo
Node
Unity
Stack
Cabal
SBT
Maven
Gradle
CMake
Unreal
Jupyter
Python
Pixi
Composer
Pub
Elixir
Swift
Zig
Godot4
Dotnet
Turborepo
Terraform
Cocoapods